<?php

namespace Drupal\grant\Access;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Routing\Access\AccessInterface;
use Drupal\Component\Utility\Html;
use Symfony\Component\Routing\Route;

/**
 * Determines access to routes based on permissions and roles via grant.
 */
class GrantAccessCheck implements AccessInterface {

  /**
   * Checks access.
   *
   * @param \Symfony\Component\Routing\Route $route
   *   The route to check against.
   *
   * @return \Drupal\Core\Access\AccessResultInterface
   *   The access result.
   */
  public function access(Route $route) {
    $gra_config_raw = $route->getRequirement('_grant_access_check');
    if ($gra_config_raw === NULL) {
      return AccessResult::neutral();
    }
    $gra_config = explode("|", $gra_config_raw);

    $e_type = '';
    $e_uuid = '';
    $e_id = 0;
    $arg_uuid = FALSE;

    if (isset($gra_config[1])) {
      $gra_config_arg_list = explode(',', trim($gra_config[1]));
      $args_raw = explode('/', \Drupal::service('path.current')->getPath());
      foreach ($gra_config_arg_list as $gra_config_arg_raw) {
        $key_value = explode(':', trim($gra_config_arg_raw));
        $key = trim($key_value[0]);
        $value = trim($key_value[1]);
        if ($key == 'type') {
          $e_type = Html::escape($args_raw[$value]);
        }
        if ($key == 'uuid') {
          $arg = $value;
          $arg_uuid = TRUE;
        }
        if ($key == 'id') {
          $arg = $value;
        }
      }

      $arg = Html::escape($args_raw[$value]);
      if ($arg_uuid == TRUE) {
        $e_uuid = (string) $arg;
      }
      else {
        $e_id = (int) $arg;
        $e_uuid = \Drupal::entityTypeManager()->getStorage($e_type)->load($e_id)->uuid;
      }
    }

    // Function userAssignedGrantHasPermission also check on global assigned roles.
    $access = \Drupal::service('grant.main')->userAssignedGrantHasPermission('current', trim($gra_config[0]), $e_type, $e_uuid);
    return AccessResult::allowedIf($access);
  }

}
