<?php

namespace Drupal\grant\Entity;

use Drupal\Core\Config\Entity\ConfigEntityBase;
use Drupal\grant\GrantConfigInterface;

/**
 * Defines the grant config entity type.
 *
 * @ConfigEntityType(
 *   id = "grant_config",
 *   label = @Translation("Grant Config"),
 *   label_collection = @Translation("Grant Configs"),
 *   label_singular = @Translation("grant config"),
 *   label_plural = @Translation("grant configs"),
 *   label_count = @PluralTranslation(
 *     singular = "@count grant config",
 *     plural = "@count grant configs",
 *   ),
 *   handlers = {
 *     "list_builder" = "Drupal\grant\GrantConfigListBuilder",
 *     "form" = {
 *       "add" = "Drupal\grant\Form\GrantConfigForm",
 *       "edit" = "Drupal\grant\Form\GrantConfigForm",
 *       "delete" = "Drupal\Core\Entity\EntityDeleteForm"
 *     }
 *   },
 *   config_prefix = "grant_config",
 *   admin_permission = "administer grant",
 *   links = {
 *     "collection" = "/admin/structure/grant-config",
 *     "add-form" = "/admin/structure/grant-config/add",
 *     "edit-form" = "/admin/structure/grant-config/{grant_config}",
 *     "delete-form" = "/admin/structure/grant-config/{grant_config}/delete"
 *   },
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "label",
 *     "uuid" = "uuid"
 *   },
 *   config_export = {
 *     "id",
 *     "label",
 *     "parentfields",
 *     "assignroles"
 *   }
 * )
 */
class GrantConfig extends ConfigEntityBase implements GrantConfigInterface {

  /**
   * The grant config ID.
   *
   * @var string
   */
  protected $id;

  /**
   * The grant config label.
   *
   * @var string
   */
  protected $label;

  /**
   * The grant config status.
   *
   * @var bool
   */
  protected $status;

  /**
   * The grant config parent fields.
   *
   * @var string
   */
  protected $parentfields;

  /**
   * The grant config assign roles.
   *
   * @var string
   */
  protected $assignroles;

  /**
   * Get grant config status.
   */
  public function getStatus() {
    return $this->status;
  }

  /**
   * Get parentfields.
   */
  public function getParentFields() {
    $lines = \Drupal::service('grant.main')->textfieldToArray($this->parentfields);
    return $lines;
  }

  /**
   * Get assignroles.
   */
  public function getAssignRoles() {
    $lines = \Drupal::service('grant.main')->textfieldToArray($this->assignroles);
    $assignroles = [];
    foreach ($lines as $line) {
      $colon = array_map('trim', explode(':', $line));
      $assignroles[$colon[0]] = array_map('trim', explode(',', $colon[1]));
    }
    return $assignroles;
  }

}
