<?php

namespace Drupal\grant\Form;

use Drupal\Core\Entity\EntityForm;
use Drupal\Core\Form\FormStateInterface;

/**
 * Grant Config form.
 *
 * @property \Drupal\grant\GrantConfigInterface $entity
 */
class GrantConfigForm extends EntityForm {

  /**
   * {@inheritdoc}
   */
  public function form(array $form, FormStateInterface $form_state) {

    $form = parent::form($form, $form_state);

    $form['label'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Label'),
      '#maxlength' => 255,
      '#default_value' => $this->entity->label(),
      '#description' => $this->t('Maybe use the related entity type label e.g. "Node"! Be aware of the correct Machine Name.'),
      '#required' => TRUE,
    ];

    $form['id'] = [
      '#type' => 'machine_name',
      '#title' => $this->t('Machine Name'),
      '#default_value' => $this->entity->id(),
      '#machine_name' => [
        'exists' => '\Drupal\grant\Entity\GrantConfig::load',
      ],
      '#description' => $this->t('Entity type (machine name) to add grant config e.g. "node"!'),
    ];

    $form['status'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Status'),
      '#default_value' => $this->entity->status(),
      '#description' => $this->t('Config enabled on this entity type.'),
    ];

    $form['parentfields'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Parent fields'),
      '#default_value' => $this->entity->get('parentfields'),
      '#description' => $this->t('List of parent entity reference fields based on entity id (core) or entity uuid (entity_reference_uuid) to "follow" granted roles on other entities. Separate fields with newlines.'),
    ];

    $form['assignroles'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Assign roles'),
      '#default_value' => $this->entity->get('assignroles'),
      '#description' => $this->t('List of roles with permission to assign roles on this entity type e.g. "group_admin_role: group_moderator, group_guest". Separate assignroles sets with newlines.'),
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function save(array $form, FormStateInterface $form_state) {
    $result = parent::save($form, $form_state);
    $message_args = ['%label' => $this->entity->label()];
    $message = $result == SAVED_NEW
      ? $this->t('Created new grant config %label.', $message_args)
      : $this->t('Updated grant config %label.', $message_args);
    $this->messenger()->addStatus($message);
    $form_state->setRedirectUrl($this->entity->toUrl('collection'));
    return $result;
  }

}
