<?php

namespace Drupal\grant\Form;

use Drupal\grant\Entity\Grant;
use Drupal\user\Entity\User;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\user\Entity\Role;

/**
 * Provides a Grant form.
 */
class GrantInviteForm extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'grant_grant_invite';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, $type = '', $uuid = '') {
    $parameter = [];

    $current_user_id = \Drupal::currentUser()->id();
    $current_user = User::load($current_user_id);
    $current_user_uuid = $current_user->uuid();

    $parameter['entity_type'] = $type;
    $parameter['entity_uuid'] = $uuid;
    $parameter['user'] = $current_user_uuid;

    $roles = Role::loadMultiple();

    foreach ($roles as $key => $role) {
      $value = $role->label();
      $roles_select[$key] = $value;
    }

    $form['roles'] = [
      '#title' => 'Grant Role',
      '#type' => 'select',
      '#key_type' => 'associative',
      '#options' => $roles_select,
      '#description' => $this->t('Which role you want to assign.'),
      '#weight' => 1,
    ];

    $form['email'] = [
      '#type' => 'email',
      '#title' => $this->t('Grant email address'),
      '#description' => $this->t('Email address of a person you want to invite.'),
      '#weight' => 0,
    ];

    $form['note'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Note'),
      '#description' => $this->t('Optional adminitration note.'),
    ];

    $form['actions'] = [
      '#type' => 'actions',
    ];
    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Invite user'),
    ];

    $form_state->setStorage($parameter);
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    $parameter = $form_state->getStorage();
    // ToDo: Do validation
    //    if (mb_strlen($form_state->getValue('message')) < 10) {
    //      $form_state->setErrorByName('message', $this->t('Message should be at least 10 characters.'));
    //    }.
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $parameter = $form_state->getStorage();
    $form_values = $form_state->getValues();

    $form_values['mail'];
    $grant = Grant::create([
      'status' => 0,
      'user' => $current_user_uuid,
      'email' => $form_values['email'],
      'entity_type' => $parameter['entity_type'],
      'entity_uuid' => $parameter['entity_uuid'],
      'timer' => 1,
    ]);

    $grant->save();
    $this->messenger()->addStatus($this->t('The grant invitation has been saved.'));
    $form_state->setRedirect('<front>');
  }

}
